﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.Application.Orders;
using Hotline.Authentications;
using Hotline.Caching.Interfaces;
using Hotline.EventBus;
using Hotline.FlowEngine.Notifications;
using Hotline.FlowEngine.Workflows;
using Hotline.Orders;
using Hotline.Settings;
using Hotline.Share.Dtos.FlowEngine;
using Hotline.Share.Enums.FlowEngine;
using Hotline.Snapshot.Notifications;
using MediatR;
using XF.Domain.Exceptions;

namespace Hotline.Application.Orders.Handles.Snapshot
{
    /// <summary>
    /// 需求：坐席派给网格员的安全隐患工单若未推送成功超过4小时或者网格员超过4小时没回复，则自动流转到标注节点待标注列表
    /// </summary>
    public class GuiderSystemTimeoutHandler : INotificationHandler<GuiderSystemTimeOutBackNotification>
    {
        private readonly ISystemSettingCacheManager _systemSettingCacheManager;
        private readonly IOrderApplication _orderApplication;
        private readonly ISystemLogRepository _systemLogRepository;

        public GuiderSystemTimeoutHandler(
            ISystemSettingCacheManager systemSettingCacheManager,
            IOrderApplication orderApplication
,
            ISystemLogRepository systemLogRepository)
        {
            _systemSettingCacheManager = systemSettingCacheManager;
            _orderApplication = orderApplication;
            _systemLogRepository = systemLogRepository;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(GuiderSystemTimeOutBackNotification notification, CancellationToken cancellationToken)
        {
            _systemLogRepository.Add("网格员超时未回复", notification.OrderId, "收到事件", "", 1);
            if (_systemSettingCacheManager.Snapshot)
            {
                await _orderApplication.HandleFromWanggeyuanToMaskAsync(notification.OrderId, cancellationToken);
            }
        }
    }
}
