﻿using SqlSugar;
using System.ComponentModel;
using XF.Domain.Repository;

namespace Hotline.Statistics
{
    /// <summary>
	/// 中心报表统计
	/// </summary>
	[Description("中心报表统计")]
    [SugarIndex("index_statisticsCenter_insertTime", nameof(StatisticsCenter.Time), OrderByType.Desc)]
    public class StatisticsCenter : CreationEntity
    {
        /// <summary>
        /// 电话总量
        /// </summary>
        [SugarColumn(ColumnDescription = "电话总量")]
        public int CallNum { get; set; }

        /// <summary>
        /// 居家养老电话总量
        /// </summary>
        [SugarColumn(ColumnDescription = "居家养老电话总量")]
        public int FamilyCallNum { get; set; }

        /// <summary>
        /// 居家养老呼入接通量
        /// </summary>
        [SugarColumn(ColumnDescription = "居家养老呼入接通量")]
        public int FamilyCallConnNum { get; set; }

        /// <summary>
        /// 有效(接通)
        /// </summary>
        [SugarColumn(ColumnDescription = "有效(接通)")]
        public int CallInConn { get; set; }

        /// <summary>
        /// 无效(未接通)
        /// </summary>
        [SugarColumn(ColumnDescription = "无效(未接通)")]
        public int CallInNotConn { get; set; }

        /// <summary>
        /// 在IVR中挂断
        /// </summary>
        [SugarColumn(ColumnDescription = "在IVR中挂断")]
        public int CallInIVR { get; set; }

        /// <summary>
        /// 在队列中挂断
        /// </summary>
        [SugarColumn(ColumnDescription = "在队列中挂断")]
        public int CallInQueue { get; set; }

        /// <summary>
        /// 已回访量
        /// </summary>
        [SugarColumn(ColumnDescription = "已回访量")]
        public int VisitAlreadyNum { get; set; }

        /// <summary>
        /// 待回访量
        /// </summary>
        [SugarColumn(ColumnDescription = "待回访量")]
        public int VisitWaitNum { get; set; }

        /// <summary>
        /// 坐席满意度
        /// </summary>
        [SugarColumn(Length = 10, DecimalDigits = 6, ColumnDescription = "坐席满意度")]
        public decimal SatisfactionSeat { get; set; }

        /// <summary>
        /// 部门满意度
        /// </summary>
        [SugarColumn(Length = 10, DecimalDigits = 6, ColumnDescription = "部门满意度")]
        public decimal SatisfactionDepartment { get; set; }

        /// <summary>
        /// 来件总计
        /// </summary>
        [SugarColumn(ColumnDescription = "来件总计")]
        public int OrderAllNum { get; set; }

        /// <summary>
        /// 有效
        /// </summary>
        [SugarColumn(ColumnDescription = "有效")]
        public int OrderNormalNum { get; set; }

        /// <summary>
        /// 无效
        /// </summary>
        [SugarColumn(ColumnDescription = "无效")]
        public int OrderInvalidNum { get; set; }

        /// <summary>
        /// 已办结信件
        /// </summary>
        [SugarColumn(ColumnDescription = "已办结信件")]
        public int OrderEndNum { get; set; }

        /// <summary>
        /// 在办信件
        /// </summary>
        [SugarColumn(ColumnDescription = "在办信件")]
        public int OrderWaitNum { get; set; }

        /// <summary>
        /// 来源总量
        /// </summary>
        [SugarColumn(ColumnDescription = "来源总量")]
        public int FromAllNum { get; set; }

        /// <summary>
        /// 电话
        /// </summary>
        [SugarColumn(ColumnDescription = "电话")]
        public int FromPhone { get; set; }

        /// <summary>
        /// 英特网
        /// </summary>
        [SugarColumn(ColumnDescription = "英特网")]
        public int FromInternet { get; set; }

        /// <summary>
        /// 其它
        /// </summary>
        [SugarColumn(ColumnDescription = "其它")]
        public int FromOther { get; set; }

        /// <summary>
        /// 自建
        /// </summary>
        [SugarColumn(ColumnDescription = "自建")]
        public int FromSelfBuild { get; set; }

        /// <summary>
        /// 微信
        /// </summary>
        [SugarColumn(ColumnDescription = "微信")]
        public int FromWeChat { get; set; }

        /// <summary>
        /// 微博
        /// </summary>
        [SugarColumn(ColumnDescription = "微博")]
        public int FromWeibo { get; set; }

        /// <summary>
        /// APP
        /// </summary>
        [SugarColumn(ColumnDescription = "APP")]
        public int FromApp { get; set; }

        /// <summary>
        /// 智慧宜宾
        /// </summary>
        [SugarColumn(ColumnDescription = "智慧宜宾")]
        public int FromSmartYibin { get; set; }

        /// <summary>
        /// 综治平台
        /// </summary>
        [SugarColumn(ColumnDescription = "综治平台")]
        public int FromPlatformZZ { get; set; }

        /// <summary>
        /// 省12328平台
        /// </summary>
        [SugarColumn(ColumnDescription = "省12328平台")]
        public int FromPlatform12328 { get; set; }

        /// <summary>
        /// 市长与网民
        /// </summary>
        [SugarColumn(ColumnDescription = "市长与网民")]
        public int FromMayorNetizen { get; set; }

        /// <summary>
        /// 宜宾融媒体
        /// </summary>
        [SugarColumn(ColumnDescription = "宜宾融媒体")]
        public int FromPlatformRMT { get; set; }

        /// <summary>
        /// 省12345平台
        /// </summary>
        [SugarColumn(ColumnDescription = "省12345平台")]
        public int FromPlatformProvince { get; set; }

        /// <summary>
        /// 省政民互动
        /// </summary>
        [SugarColumn(ColumnDescription = "省政民互动")]
        public int FromPlatformZMHD { get; set; }

        /// <summary>
        /// 宜办事
        /// </summary>
        [SugarColumn(ColumnDescription = "宜办事")]
        public int FromPlatformYBS { get; set; }

        /// <summary>
        /// 市州互转
        /// </summary>
        [SugarColumn(ColumnDescription = "市州互转")]
        public int FromPlatformSZHZ { get; set; }

        /// <summary>
        /// 宜宾110平台
        /// </summary>
        [SugarColumn(ColumnDescription = "宜宾110平台")]
        public int FromPlatform110 { get; set; }

        /// <summary>
        /// 办不成事反映窗口
        /// </summary>
        [SugarColumn(ColumnDescription = "办不成事反映窗口")]
        public int FromPlatformBBCS { get; set; }

        /// <summary>
        /// i宜宾
        /// </summary>
        [SugarColumn(ColumnDescription = "i宜宾")]
        public int FromPlatformIYB { get; set; }

        /// <summary>
        /// 统计日期
        /// </summary>
        [SugarColumn(ColumnDescription = "统计日期")]
        public DateTime Time { get; set; }

        /// <summary>
        /// 统计时限
        /// </summary>
        [SugarColumn(ColumnDescription = "统计时限")]
        public int Month { get; set; }

        /// <summary>
        /// 入库时间
        /// </summary>
        [SugarColumn(ColumnDescription = "入库时间")]

        public DateTime InsertTime { get; set; }
    }
}
